window.Gleam.initSearch([{"doc":"tobble","title":"tobble","content":"# tobble\n\n[![Package Version](https://img.shields.io/hexpm/v/tobble)](https://hex.pm/packages/tobble)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/tobble/)\n\nTobble is a table library for Gleam, which makes it as easy as\npossible to render tables from simple output. It does provide some\ncustomization options, but they are not very expansive, as Tobble does not\naim to be a full layout library. Rather, it aims to make it simple to make\nbeautiful output for your programs.\n\n```gleam\nimport gleam/io\nimport tobble\n\npub fn main() {\n  let assert Ok(table) =\n    tobble.builder()\n    |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n    |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n    |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n    |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n    |&gt; tobble.build()\n\n  io.println(tobble.render(table))\n}\n```\n\n```text\n+---------+--------------+\n|         | Output       |\n+---------+--------------+\n| Stage 1 | Wibble       |\n| Stage 2 | Wobble       |\n| Stage 3 | WibbleWobble |\n+---------+--------------+\n```\n\n## Installation\n\n```sh\ngleam add tobble@2\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/tobble&gt;.\n\n## Development\n\nTobble is built using Gleam 1.6. If you would like to hack on Tobble, you\ncan run the tests with `gleam test`.\n","url":"index.html"},{"doc":"tobble/table_render_opts","title":"Option","content":"pub opaque type Option\n\n\nSynonyms:\ntobble/table_render_opts.Option\ntobble/table_render_opts Option","url":"tobble/table_render_opts.html#Option"},{"doc":"tobble/table_render_opts","title":"column_width","content":"pub fn column_width(width: Int) -&gt; Option\n Render the table where each column&#39;s text has the given width. If a width\n less than 1 is given, this will default to 1. By default, columns are as\n wide as the longest row within them.\nSynonyms:\ntobble/table_render_opts.column_width\ntobble/table_render_opts column_width","url":"tobble/table_render_opts.html#column_width"},{"doc":"tobble/table_render_opts","title":"hide_title","content":"pub fn hide_title() -&gt; Option\n Render a table that has a title set, but without its title.\nSynonyms:\ntobble/table_render_opts.hide_title\ntobble/table_render_opts hide_title","url":"tobble/table_render_opts.html#hide_title"},{"doc":"tobble/table_render_opts","title":"horizontal_rules_after_every_row","content":"pub fn horizontal_rules_after_every_row() -&gt; Option\n Renders the table with every row the header having a horizontal rule beneath it.\n\n text\n +---------+--------------+\n |         | Output       |\n +---------+--------------+\n | Stage 1 | Wibble       |\n +---------+--------------+\n | Stage 2 | Wobble       |\n +---------+--------------+\n | Stage 3 | WibbleWobble |\n +---------+--------------+\n \nSynonyms:\ntobble/table_render_opts.horizontal_rules_after_every_row\ntobble/table_render_opts horizontal_rules_after_every_row","url":"tobble/table_render_opts.html#horizontal_rules_after_every_row"},{"doc":"tobble/table_render_opts","title":"horizontal_rules_only_after_header","content":"pub fn horizontal_rules_only_after_header() -&gt; Option\n Renders the table with only the header having a horizontal rule beneath it. This is the default setting.\n\n text\n +---------+--------------+\n |         | Output       |\n +---------+--------------+\n | Stage 1 | Wibble       |\n | Stage 2 | Wobble       |\n | Stage 3 | WibbleWobble |\n +---------+--------------+\n \nSynonyms:\ntobble/table_render_opts.horizontal_rules_only_after_header\ntobble/table_render_opts horizontal_rules_only_after_header","url":"tobble/table_render_opts.html#horizontal_rules_only_after_header"},{"doc":"tobble/table_render_opts","title":"line_type_ascii","content":"pub fn line_type_ascii() -&gt; Option\n Render the table with ASCII characters for the borders.\n This is the default setting.\n\n text\n +---------+--------------+\n |         | Output       |\n +---------+--------------+\n | Stage 1 | Wibble       |\n | Stage 2 | Wobble       |\n | Stage 3 | WibbleWobble |\n +---------+--------------+\n \nSynonyms:\ntobble/table_render_opts.line_type_ascii\ntobble/table_render_opts line_type_ascii","url":"tobble/table_render_opts.html#line_type_ascii"},{"doc":"tobble/table_render_opts","title":"line_type_blank","content":"pub fn line_type_blank() -&gt; Option\n Renders the table with spaces for the borders.\n Note that this does not strip trailing spaces, the borders that\n you see in other line types are simply replaced with spaces. It\n will, however, remove the top and bottom borders for you.\n\n text\n             Output\n\n   Stage 1   Wibble\n   Stage 2   Wobble\n   Stage 3   WibbleWobble\n \nSynonyms:\ntobble/table_render_opts.line_type_blank\ntobble/table_render_opts line_type_blank","url":"tobble/table_render_opts.html#line_type_blank"},{"doc":"tobble/table_render_opts","title":"line_type_box_drawing_characters","content":"pub fn line_type_box_drawing_characters() -&gt; Option\n Renders the table with box drawing characters for the borders.\n\n &lt;pre&gt;&lt;code style=&quot;font-family: monospace;&quot; class=&quot;language-plaintext&quot;&gt;┌─────────┬──────────────┐\n │         │ Output       │\n ├─────────┼──────────────┤\n │ Stage 1 │ Wibble       │\n │ Stage 2 │ Wobble       │\n │ Stage 3 │ WibbleWobble │\n └─────────┴──────────────┘&lt;/code&gt;&lt;/pre&gt;\nSynonyms:\ntobble/table_render_opts.line_type_box_drawing_characters\ntobble/table_render_opts line_type_box_drawing_characters","url":"tobble/table_render_opts.html#line_type_box_drawing_characters"},{"doc":"tobble/table_render_opts","title":"line_type_rounded_corner_box_drawing_characters","content":"pub fn line_type_rounded_corner_box_drawing_characters() -&gt; Option\n Renders the table with box drawing characters for the borders, but\n with rounded corners.\n\n &lt;pre&gt;&lt;code style=&quot;font-family: monospace;&quot; class=&quot;language-plaintext&quot;&gt;╭─────────┬──────────────╮\n │         │ Output       │\n ├─────────┼──────────────┤\n │ Stage 1 │ Wibble       │\n │ Stage 2 │ Wobble       │\n │ Stage 3 │ WibbleWobble │\n ╰─────────┴──────────────╯&lt;/code&gt;&lt;/pre&gt;\nSynonyms:\ntobble/table_render_opts.line_type_rounded_corner_box_drawing_characters\ntobble/table_render_opts line_type_rounded_corner_box_drawing_characters","url":"tobble/table_render_opts.html#line_type_rounded_corner_box_drawing_characters"},{"doc":"tobble/table_render_opts","title":"no_horizontal_rules","content":"pub fn no_horizontal_rules() -&gt; Option\n Renders the table without any horizontal rules interleaved with the table&#39;s rows.\n\n text\n +---------+--------------+\n |         | Output       |\n | Stage 1 | Wibble       |\n | Stage 2 | Wobble       |\n | Stage 3 | WibbleWobble |\n +---------+--------------+\n \nSynonyms:\ntobble/table_render_opts.no_horizontal_rules\ntobble/table_render_opts no_horizontal_rules","url":"tobble/table_render_opts.html#no_horizontal_rules"},{"doc":"tobble/table_render_opts","title":"table_width","content":"pub fn table_width(width: Int) -&gt; Option\n Render the table with a width of, at most, the given width. Note that this\n is best effort, and there are pathological cases where Tobble will decide\n to render your tables slightly wider than requested (e.g. requesting a\n width too small to even fit the table borders). By default, the table\n width is unconstrained.\nSynonyms:\ntobble/table_render_opts.table_width\ntobble/table_render_opts table_width","url":"tobble/table_render_opts.html#table_width"},{"doc":"tobble/table_render_opts","title":"title_position_bottom","content":"pub fn title_position_bottom() -&gt; Option\n Place the title above the table. If the table does not have a title set, this option is ignored.\nSynonyms:\ntobble/table_render_opts.title_position_bottom\ntobble/table_render_opts title_position_bottom","url":"tobble/table_render_opts.html#title_position_bottom"},{"doc":"tobble/table_render_opts","title":"title_position_top","content":"pub fn title_position_top() -&gt; Option\n Place the title above the table. If the table does not have a title set, this option is ignored.\n By default, the title will render at the top.\nSynonyms:\ntobble/table_render_opts.title_position_top\ntobble/table_render_opts title_position_top","url":"tobble/table_render_opts.html#title_position_top"},{"doc":"tobble/table_render_opts","title":"tobble/table_render_opts","content":" Configure the way your table is rendered. Every function in this module\n will return an `Option` type that can be passed to the render functions\n of the `tobble` module.","url":"tobble/table_render_opts.html"},{"doc":"tobble","title":"Builder","content":"pub opaque type Builder\n `Builder` is a type used to help you build tables. See `builder` for more details.\n\nSynonyms:\ntobble.Builder\ntobble Builder","url":"tobble.html#Builder"},{"doc":"tobble","title":"BuilderError","content":"pub type BuilderError {\n  InconsistentColumnCountError(expected: Int, got: Int)\n  EmptyTableError\n  EmptyTitleError\n}\n\nInconsistentColumnCountError(expected: Int, got: Int)\n Returned when not all rows have the same number of columns.\n\n **Why is this an error?** It is not possible to render a rectangular\n                           table if any row has a different number of\n                           columns than another.\n\nEmptyTableError\n Returned when attempting to build a table with no rows.\n\n **Why is this an error?** It is somewhat unclear how to render this, and\n                           is left as an error so callers can handle it\n                           however is best for their application.\n\nEmptyTitleError\n Returned when attempting to build a table with an empty string as the title.\n\n **Why is this an error?** It is somewhat unclear how to render this, and\n                           is likely the result of a bug in your app.\n\nSynonyms:\ntobble.BuilderError\ntobble BuilderError","url":"tobble.html#BuilderError"},{"doc":"tobble","title":"Table","content":"pub opaque type Table\n `Table` is the central type of Tobble. It holds the data you wish to display,\n without regard for how you render it. These can be built using `builder`/`build`.\n\nSynonyms:\ntobble.Table\ntobble Table","url":"tobble.html#Table"},{"doc":"tobble","title":"add_row","content":"pub fn add_row(\n  to builder: Builder,\n  columns columns: List(String),\n) -&gt; Builder\n Add a row to a table that is being built. Every call to `add_row` for a given\n `Builder` must have the same number of columns, or an\n `InconsistentColumnCountError` will be returned when `build` is called.\nSynonyms:\ntobble.add_row\ntobble add_row","url":"tobble.html#add_row"},{"doc":"tobble","title":"build","content":"pub fn build(\n  with builder: Builder,\n) -&gt; Result(Table, BuilderError)\n Build a `Table` from the given `Builder`. If an invalid operation was\n performed when constructing the `Builder`, an error will be returned.\nSynonyms:\ntobble.build\ntobble build","url":"tobble.html#build"},{"doc":"tobble","title":"builder","content":"pub fn builder() -&gt; Builder\n Create a new `Builder` for table generation. Once you have completed\n adding your rows to this with `add_row`, you should call `build` to\n generate a `Table`.\nSynonyms:\ntobble.builder\ntobble builder","url":"tobble.html#builder"},{"doc":"tobble","title":"render","content":"pub fn render(table table: Table) -&gt; String\n Render the given table to a `String`, with the default options.\n The output can be customized by using `render_with_options`.\n\n # Example\n\n \n let assert Ok(table) =\n     tobble.builder()\n     |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n     |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n     |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n     |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n     |&gt; tobble.build()\n\n io.println(tobble.render(table))\n \n\n text\n +---------+--------------+\n |         | Output       |\n +---------+--------------+\n | Stage 1 | Wibble       |\n | Stage 2 | Wobble       |\n | Stage 3 | WibbleWobble |\n +---------+--------------+\n \nSynonyms:\ntobble.render\ntobble render","url":"tobble.html#render"},{"doc":"tobble","title":"render_iter","content":"pub fn render_iter(\n  table table: Table,\n  options options: List(Option),\n) -&gt; Yielder(String)\n Render the given table to a `Yielder`. Each element of the `Yielder` will\n produce a single line of output, without a trailing newline. Note that\n options are applied in order, so if duplicate or conflicting options\n are given, the last one will win.\n\n # Example\n\n \n let assert Ok(table) =\n   tobble.builder()\n   |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n   |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n   |&gt; tobble.build()\n\n\n table\n |&gt; tobble.render_iter(options: [])\n |&gt; yielder.each(io.println)\n \n\n text\n +---------+--------------+\n |         | Output       |\n +---------+--------------+\n | Stage 1 | Wibble       |\n | Stage 2 | Wobble       |\n | Stage 3 | WibbleWobble |\n +---------+--------------+\n \nSynonyms:\ntobble.render_iter\ntobble render_iter","url":"tobble.html#render_iter"},{"doc":"tobble","title":"render_with_options","content":"pub fn render_with_options(\n  table table: Table,\n  options options: List(Option),\n) -&gt; String\n Render the given table to a `String`, with extra options (found in\n `tobble/table_render_opts`). Note that options are applied in order, so if\n duplicate or conflicting options are given, the last one will win.\n\n\n \n let assert Ok(table) =\n   tobble.builder()\n   |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n   |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n   |&gt; tobble.build()\n\n io.println(\n   tobble.render_with_options(table, options: [\n     table_render_opts.column_width(6),\n     table_render_opts.horizontal_rules_after_every_row(),\n ]),\n)\n \n\n text\n +--------+--------+\n |        | Output |\n +--------+--------+\n | Stage  | Wibble |\n | 1      |        |\n +--------+--------+\n | Stage  | Wobble |\n | 2      |        |\n +--------+--------+\n | Stage  | Wibble |\n | 3      | Wobble |\n +--------+--------+\nSynonyms:\ntobble.render_with_options\ntobble render_with_options","url":"tobble.html#render_with_options"},{"doc":"tobble","title":"set_title","content":"pub fn set_title(\n  to builder: Builder,\n  title title: String,\n) -&gt; Builder\n Set a title for a table that is being built. The title must be a non-empty\n string or a `TitleEmptyError` will be returned when `build` is called.\n\n # Example\n\n \n let assert Ok(table) =\n   tobble.builder()\n   |&gt; tobble.set_title(&quot;Setup&quot;)\n   |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n   |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n   |&gt; tobble.build()\n\n io.println(tobble.render(table))\n \n\n \n          Setup\n +---------+--------------+\n |         | Output       |\n +---------+--------------+\n | Stage 1 | Wibble       |\n | Stage 2 | Wobble       |\n | Stage 3 | WibbleWobble |\n +---------+--------------+\n \nSynonyms:\ntobble.set_title\ntobble set_title","url":"tobble.html#set_title"},{"doc":"tobble","title":"title","content":"pub fn title(table: Table) -&gt; Option(String)\n Get the title of a table, if there is one.\n\n # Example\n\n \n let assert Ok(table) =\n   tobble.builder()\n   |&gt; tobble.set_title(&quot;Setup&quot;)\n   |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n   |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n   |&gt; tobble.build()\n\n io.debug(tobble.title(table))\n \n\n \n Some(&quot;Setup&quot;)\n \nSynonyms:\ntobble.title\ntobble title","url":"tobble.html#title"},{"doc":"tobble","title":"to_list","content":"pub fn to_list(table: Table) -&gt; List(List(String))\n Convert an existing table to a list of its rows.\n\n # Example\n\n \n let assert Ok(table) =\n   tobble.builder()\n   |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n   |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n   |&gt; tobble.build()\n\n io.debug(tobble.to_list(table))\n \n\n \n [\n   [&quot;&quot;, &quot;Output&quot;],\n   [&quot;Stage 1&quot;, &quot;Wibble&quot;],\n   [&quot;Stage 2&quot;, &quot;Wobble&quot;],\n   [&quot;Stage 3&quot;, &quot;WibbleWobble&quot;]\n ]\n \nSynonyms:\ntobble.to_list\ntobble to_list","url":"tobble.html#to_list"},{"doc":"tobble","title":"tobble","content":" Tobble is a table library for Gleam, which makes it as easy as\n possible to render tables from simple output. It does provide some\n customization options, but they are not very expansive, as Tobble does not\n aim to be a full layout library. Rather, it aims to make it simple to make\n beautiful output for your programs.\n\n ```gleam\n import gleam/io\n import tobble\n\n pub fn main() {\n   let assert Ok(table) =\n     tobble.builder()\n     |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n     |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n     |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n     |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n     |&gt; tobble.build()\n\n   io.println(tobble.render(table))\n }\n ```\n\n ```text\n +---------+--------------+\n |         | Output       |\n +---------+--------------+\n | Stage 1 | Wibble       |\n | Stage 2 | Wobble       |\n | Stage 3 | WibbleWobble |\n +---------+--------------+\n ```","url":"tobble.html"}]);